@font-face {
    /* https://github.com/VanillaandCream/Palanquin (OFL) */
    font-family: 'Palanquin-Medium';
    src: url('../fonts/Palanquin-Medium.ttf') format('truetype');
    font-weight: normal;
    font-style: normal;
}

@font-face {
    /* https://github.com/VanillaandCream/Palanquin (OFL) */
    font-family: 'Palanquin-SemiBold';
    src: url('../fonts/Palanquin-SemiBold.ttf') format('truetype');
    font-weight: normal;
    font-style: normal;
}

@font-face {
    /* https://github.com/VanillaandCream/Palanquin (OFL) */
    font-family: 'Palanquin-Regular';
    src: url('../fonts/Palanquin-Regular.ttf') format('truetype');
    font-weight: normal;
    font-style: normal;
}

@font-face {
    /* https://github.com/VanillaandCream/Palanquin (OFL) */
    font-family: 'Palanquin-ExtraLight';
    src: url('../fonts/Palanquin-ExtraLight.ttf') format('truetype');
    font-weight: 300;
    font-style: normal;
}

body {
    font-family: "Palanquin-Regular", sans-serif;
    background: #f3f3f3;
}

header {
    border-bottom: 1px solid #ddd;
    padding: 10px 0 20px;
    background: #fff;
}

.header-meat {
    max-width: 720px;
    margin: 0 auto;
    text-align: center;
}

.logo {
    max-width: 50px;
    display: inline-block;

}

.logo img {
    display: block;
    width: 100%;
    vertical-align: middle
}

.status-area {
    max-width: 720px;
    margin: 0 auto;
    position: relative;
}

.device-id {
    font-family: 'Palanquin-ExtraLight', sans-serif;
    font-size: 9pt;
    border-bottom: 1px solid #ddd;
    padding-bottom: 10px;
    text-align: center;
}

.statuses {
    list-style: none;
    margin: 0;
    padding-left: 0;
}

.statuses li {
    display: inline-block;
    font-size: 10pt;
    margin-right: 20px;
    position: relative;
    padding: 0 10px 0 25px;
    font-size: 10pt;
    line-height: 1.3;
    font-family: 'Palanquin-ExtraLight', sans-serif;
    text-transform: uppercase;
}

.statuses li a {
    color: #666;
    text-decoration: none;
}

.statuses li a:hover {
    color: #666;
    text-decoration: underline;
}

.statuses li:before {
    border-radius: 100px;
    position: absolute;
    left: 8px;
    top: 10px;
    width: 8px;
    height: 8px;
    content: " ";
}

.statuses span {
    display: block;
    font-family: 'Palanquin-Regular', sans-serif;
    font-size: 7pt;
}

.ok:before {
    background: #69C63C;
}

.not-ok:before {
    background: #ccc;
}

.panel {
    border-radius: 10px;
    max-width: 720px;
    margin: -10px auto 30px auto;
    padding: 30px;
    box-sizing: border-box;
    box-shadow: 0 0 10px #ddd;
    z-index: 1;
    position: relative;
    background: white;
}

.panel > :first-child {
    margin-top: -1em;
}

.journal-content {
    background: #2B3D50;
    padding: 10px;
    font-size: 9pt;
    color: #DAD9D9;
    border-radius: 3px;
    margin: 0;
    max-height: 500px;
    list-style: none;
    font-size: 8pt;
    font-family: monospace;
    overflow-y: scroll;
}

.log-line td {
    padding: 0 0 3px 0;
}

.log-line .timestamp {
    opacity: 0.5;
    width: 140px;
    vertical-align: text-top;
}

.log-line .message {
}

/* Device registration form. */

.device-id-group {
    margin: 10px 0;
}

.flashes {
    position: absolute;
    top: 0;
    left: 0;
    right: 0;
    list-style: none;
    margin: 0;
    padding: 0;
    font-size: 8pt;
    background: #CCC;
}

.flashes li {
    color: black;
    line-height: 1;

    border-bottom: 1px solid rgba(0,0,0,0.1);
    cursor: pointer;
}

.flashes li:last-child {
    border-bottom: none;
}

.flashes p {
    margin: 0 auto;
    max-width: 720px;
    position: relative;
    padding: 10px;
    padding-right: 20px;
}

.flashes p:after {
    content: "×";
    position: absolute;
    right: 20px;
    font-family: monospace;
    color: #999;
    font-size: 10pt;
}

.flashes li:hover p:after {
    color: #000;
}

.flashes li.dismissed {
    display: none;
}

.service-actions {
    margin-bottom: 20px
}

.service-actions form {
    display: inline;
}

td.recent_sample_uploaded {
    color: #090 !important;
}

td.recent_sample_nonuploaded {
    color: #900 !important;
}

.form-errors {
    color: red;
}

.settings-url {
    color: #0077E5
}
